\name{EC.3D}
\alias{EC.3D}

\title{Expected Euler Characteristic for a 3D Random Field}
\description{Calculates the Expected Euler Characteristic for a 3D
  Random Field thesholded a level u.}
\usage{
EC.3D(u, sigma, voxdim = c(1, 1, 1), num.vox, type = c("Normal", "t"), df = NULL)
}
\arguments{
  \item{u}{The threshold for the field.}
  \item{sigma}{The spatial covariance matrix of the field.}
  \item{voxdim}{The dimensions of the cuboid 'voxels' upon which the
    discretized field is observed.}
  \item{num.vox}{The number of voxels that make up the field.}
  \item{type}{The marginal distribution of the Random Field (only Normal
  and t at present).}
  \item{df}{The degrees of freedom of the t field.}
}
\details{The Euler Characteristic \eqn{\chi_u} (Adler, 1981) is a
  topological measure that essentially counts the number of isolated
  regions of the random field above the threshold \eqn{u} minus the
  number of 'holes'. As \eqn{u} increases the holes disappear and
  \eqn{\chi_u} counts the number of local maxima. So when \eqn{u}
  becomes close to the maximum of the random field
  \eqn{Z_{\textrm{max}}} we have that
  \deqn{P( \textrm{reject}  H_0 | H_0  \textrm{true}) =
  P(Z_{\textrm{max}}) = P(\chi_u > 0) \approx E(\chi_u)}
  where \eqn{H_0} is the null hypothesis that there is no signicant
  positive actiavtion/signal present in the field. Thus the Type I error
  of the test can be controlled through knowledge of the Expected Euler characteristic.
  }
\value{The value of the expected Euler Characteristic.
}
\references{Adler, R. (1981) \emph{The Geometry of Random Fields.}. New York: Wiley.
  Worlsey, K. J. (1994) Local maxima and the expected euler
  characteristic of excursion sets of \eqn{\chi^2}, \eqn{f} and \eqn{t)}
  fields. \emph{Advances in Applied Probability}, \bold{26}, 13-42.}

}
\author{J. L. Marchini}


\seealso{\code{\link{Threshold.RF}} }

\examples{
EC.3D(4.6, sigma = diag(1, 3), voxdim = c(1, 1, 1), num.vox = 10000)

EC.3D(4.6, sigma = diag(1, 3), voxdim = c(1, 1, 1), num.vox = 10000, type = "t", df = 100)

}
\keyword{utilities}

\eof
\name{GaussSmoothArray}
\alias{GaussSmoothArray}

\title{Spatially smooth an array with Gaussian kernel.}
\description{
  Applies a stationary Gaussian spatial smoothing kernel to a 3D or 4D array.
}
\usage{
GaussSmoothArray(x, voxdim=c(1, 1, 1), ksize=5, sigma=diag(3, 3), mask=NULL, var.norm=FALSE)
}
\arguments{
  \item{x}{The array to be smoothed.}
  \item{voxdim}{The dimensions of the \emph{vol}ume \emph{el}ements
    (voxel) that make up the array.}
  \item{ksize}{The dimensions (in number of voxels) of the 3D discrete
    smoothing kernel used to smooth the array.}
  \item{sigma}{The covariance matrix of the 3D Gaussian smoothing
    kernel. This matrix doesn't have to be non-singular; zero on the diagonal of sigma indicate no smoothing in that direction.
  }
  \item{mask}{A 3D 0-1 mask that delimits where the smoothing occurs.}
  \item{var.norm}{Logical flag indicating whether to normalize the variance of the smoothed array.}
}
\value{The smoothed array is returned.}
\author{J. L. Msrchini}

\seealso{\code{\link{GaussSmoothKernel}}}

\examples{
d <- c(10, 10, 10, 20)
mat <- array(rnorm(cumprod(d)[length(d)]), dim = d)
mat[, , 6:10, ] <- mat[, , 6:10, ] + 3
mask <- array(0, dim = d[1:3])
mask[3:8, 3:8, 3:8] <- 1
b <- GaussSmoothArray(mat, mask = mask, voxdim = c(1, 1, 1), ksize = 5, sigma = diag(1, 3))      
}
\keyword{utilities}

\eof
\name{GaussSmoothKernel}
\alias{GaussSmoothKernel}
\title{Calculates a discrete Gaussian smoothing kernel.}
\description{Calculates a simple, discrete Gaussian smoothing kernel of
  a specfic size given the covariance matrix of the Gaussian.
}
\usage{
GaussSmoothKernel(voxdim=c(1, 1, 1), ksize=5, sigma=diag(3, 3))
}
\arguments{
  \item{voxdim}{Dimensions of each voxel.}
  \item{ksize}{Dimensions of the discrete kernel size.}
  \item{sigma}{The covariance matrix of the Gaussian kernel.}
}
\value{An array of dimension (ksize,ksize,ksize) containing the
  smoothing kernel.}
\author{J. L. Marchini}


\examples{
a <- GaussSmoothKernel(voxdim=c(1,1,1), ksize=5, sigma=diag(1,3))
}
\keyword{utilities}

\eof
\name{N2G.Class.Probability}
\alias{N2G.Class.Probability}
\title{Posterior Probabilities for N2G model}
\description{Calculates the Posterior Probability of data points being
  in each class given the parameters of the N2G model.
}
\usage{
N2G.Class.Probability(data, par)
}

\arguments{
  \item{data}{The dataset (usually a vector)}
  \item{par}{The paarmeters of the model}
}
\value{Returns the Posterior Probability of data points being
  in each class given the parameters of the N2G model.
 
}
\author{J. L. Marchini}


\seealso{\code{\link{N2G.Likelihood.Ratio}},  \code{\link{N2G.Spatial.Mixture}},
  \code{\link{N2G.Density}}, \code{\link{N2G.Likelihood}} ,   \code{\link{N2G.Transform}},
 \code{\link{N2G.Fit}}    ,         \code{\link{N2G}} ,          
 \code{\link{N2G.Inverse}}   ,         \code{\link{N2G.Region}}
}


\keyword{utilities}






\eof
\name{N2G.Density}
\alias{N2G.Density}

\title{Calculates the density function for the N2G model}
\description{Calculates the density function for the N2G model
 
}
\usage{
N2G.Density(data, par)
}

\arguments{
  \item{data}{The dataset (usually a vector)}
  \item{par}{The parameters of the model.}
}
\details{Calculates the density function for the N2G model
}
\value{Returns the density at each point of the datasets
 
}
\author{J. L. Marchini}


\seealso{\code{\link{N2G.Class.Probability}},  \code{\link{N2G.Likelihood.Ratio}},  \code{\link{N2G.Spatial.Mixture}},
         \code{\link{N2G.Likelihood}} ,   \code{\link{N2G.Transform}},
 \code{\link{N2G.Fit}}    ,         \code{\link{N2G}} ,          
 \code{\link{N2G.Inverse}}   ,         \code{\link{N2G.Region}}
}



\keyword{utilities}

\eof

\name{N2G.Fit}
\alias{N2G.Fit}

\title{Optimzation function for N2G model}
\description{Function that carries out the likelihood optimzation for
  the N2G model.
}
\usage{
N2G.Fit(data, par.start, maxit, method)
}
\arguments{
  \item{data}{The dataset (usually a vector)}
  \item{par.start}{Starting values for the parameters}
  \item{maxit}{Maximum number of iterations}
  \item{method}{Optimzation method (passed to optim)}
}
\details{Numerical optimization of the N2G model likelihood.
}
\value{Returns the optimized model parameters.
}
\author{J. L. Marchini}

\seealso{\code{\link{N2G.Class.Probability}},  \code{\link{N2G.Likelihood.Ratio}},  \code{\link{N2G.Spatial.Mixture}},
         \code{\link{N2G.Likelihood}} ,   \code{\link{N2G.Transform}},
	 \code{\link{N2G.Density}}    ,         \code{\link{N2G}} ,          
 \code{\link{N2G.Inverse}}   ,         \code{\link{N2G.Region}}
}


\keyword{utilities}

\eof
\name{N2G.Inverse}
\alias{N2G.Inverse}
\title{Transform parameters of N2G model back to their real domains}
\description{Transform parameters of N2G model back to their real domains
}
\usage{
N2G.Inverse(par)
}
\arguments{
  \item{par}{Parameter vector}
}
\details{Transform parameters of N2G model back to their real domains
}
\value{Returns the transformed parameters.
}
\author{J. L. Marchini}

\seealso{\code{\link{N2G.Class.Probability}},  \code{\link{N2G.Likelihood.Ratio}},  \code{\link{N2G.Spatial.Mixture}},
 \code{\link{N2G.Density}} ,         \code{\link{N2G.Likelihood}} ,   \code{\link{N2G.Transform}},
 \code{\link{N2G.Fit}}    ,         \code{\link{N2G}} ,          
         \code{\link{N2G.Region}}
}


\keyword{utilities}

\eof
\name{N2G.Likelihood.Ratio}
\alias{N2G.Likelihood.Ratio}
\title{N2G Likelihood Ratio's
    }
\description{Calculates the ratio of the likelihood that data came from the positive Gamma distribution (activation) to the likelihood that data came from the other two distributions (Normal and negative Gamma)
}
\usage{
N2G.Likelihood.Ratio(data, par)
}
\arguments{
  \item{data}{The dataset (usually a vector)}
  \item{par}{The parameter vector for the N2G model}
}
\value{Returns the vector of likelihood ratio's
}
\author{J. L. Marchini}

 ~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{\code{\link{N2G.Class.Probability}},   \code{\link{N2G.Spatial.Mixture}},
 \code{\link{N2G.Density}} ,         \code{\link{N2G.Likelihood}} ,   \code{\link{N2G.Transform}},
 \code{\link{N2G.Fit}}    ,         \code{\link{N2G}} ,          
 \code{\link{N2G.Inverse}}   ,         \code{\link{N2G.Region}}
}


\keyword{utilities}

\eof
\name{N2G.Likelihood}
\alias{N2G.Likelihood}
\title{Calculates the (negative) Likelihood of the N2G model}
\description{Calculates the (negative) Likelihood of the N2G model
}
\usage{
N2G.Likelihood(inv.par, data)
}
\arguments{
  \item{inv.par}{A vector of transformed parameters for the N2G model}
  \item{data}{The dataset (usually a vector)}
}
\details{Calculates the (negative) Likelihood of the N2G model
}
\value{Returns (negative) Likelihood at each point of the dataset.
}
\author{J. L. Marchini}

 ~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{\code{\link{N2G.Class.Probability}},  \code{\link{N2G.Likelihood.Ratio}},  \code{\link{N2G.Spatial.Mixture}},
 \code{\link{N2G.Density}} ,       \code{\link{N2G.Transform}},
 \code{\link{N2G.Fit}}    ,         \code{\link{N2G}} ,          
 \code{\link{N2G.Inverse}}   ,         \code{\link{N2G.Region}}
}

\keyword{utilities}

\eof
\name{N2G}
\alias{N2G}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Fits the N2G model}
\description{Fits the N2G model (1 Normal and 2 Gamma's mixture model)
  to a dataset using Maximum Likelihhod.
}
\usage{
N2G(data, par.start = c(4, 2, 4, 2, 0.9, 0.05))
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{data}{The dataset.}
  \item{par.start}{The starting values for the optimization to maximize
    the likelihood. The parameters of the model are ordered in the
    vector par.start in the following way (refer to the model below)

    c(a, b, c, d, p1, p2)}
}
\details{The mixture model considered is a mixture of a standard normal
  distribution and two Gamma functions. This model is denoted N2G.
  
  x ~ p1 * N(0, 1) + p2 * Gamma(a, b) + (1 - p1 - p2) * -Gamma(c, d)
}
\value{
  A list with components
  \item{par}{The fitted parameter values.}
  \item{lims}{The upper and lower thresholds for the Normal component of
  the fitted model}
}
\author{J. L. Marchini}

\seealso{\code{\link{N2G.Class.Probability}},  \code{\link{N2G.Likelihood.Ratio}},  \code{\link{N2G.Spatial.Mixture}},
 \code{\link{N2G.Density}} ,         \code{\link{N2G.Likelihood}} ,   \code{\link{N2G.Transform}},
 \code{\link{N2G.Fit}}    ,             
 \code{\link{N2G.Inverse}}   ,         \code{\link{N2G.Region}}
}
\examples{
par <- c(3, 2, 3, 2, .3, .4)
data <- c(rnorm(10000), rgamma(2000, 10, 1), -rgamma(1400, 10, 1))
hist(data, n = 100, freq = FALSE)

q <- N2G.Fit(data, par, maxit = 10000, method = "BFGS")
p <- seq(-50, 50, .1)
lines(p, N2G.Density(p, q), col = 2)
}
\keyword{utilities}

\eof
\name{N2G.Region}
\alias{N2G.Region}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{N2G Normal component interval}
\description{Calculates the interval within which observations are
  classified as belonging to the Normal component of an N2G model.
}
\usage{
N2G.Region(par1)
}
\arguments{
  \item{par1}{The parameters of the N2G model.}
}
\value{Avector containing the upper and lower boundaries of the interval.
}
\author{J. L. Marchini}

\seealso{\code{\link{N2G.Class.Probability}},  \code{\link{N2G.Likelihood.Ratio}},  \code{\link{N2G.Spatial.Mixture}},
 \code{\link{N2G.Density}} ,         \code{\link{N2G.Likelihood}} ,   \code{\link{N2G.Transform}},
 \code{\link{N2G.Fit}}    ,         \code{\link{N2G}} ,          
 \code{\link{N2G.Inverse}} 
}

\keyword{utilities}

\eof
\name{N2G.Spatial.Mixture}
\alias{N2G.Spatial.Mixture}
\title{fMRI Spatial Mixture Modelling}
\description{Fits the spatial mixture model of Hartvig and Jensen (2000)
}
\usage{
N2G.Spatial.Mixture(data, par.start = c(4, 2, 4, 2, 0.9, 0.05), ksize, ktype = c("2D", "3D"), mask = NULL)
}
\arguments{
  \item{data}{The dataset (usually a vector)}
  \item{par.start}{Starting values for N2G model}
  \item{ksize}{Kernel size (see paper)}
  \item{ktype}{Format of kernel "2D" or "3D"}
  \item{mask}{Mask for dataset.}
}

\value{p.map = a1, par = fit$par, lims = fit$lims
  Returns a list with following components
  \item{p.map}{Posterior Probability Map of activation}
  \item{par}{Fitted parameters of the underlying N2G model}
  \item{lims}{Normal component interval for fitted model}
}
\references{Hartvig and Jensen (2000) Spatial Mixture Modelling of fMRI Data}
\author{J. L. Marchini}

\seealso{\code{\link{N2G.Class.Probability}},  \code{\link{N2G.Likelihood.Ratio}}, 
 \code{\link{N2G.Density}} ,         \code{\link{N2G.Likelihood}} ,   \code{\link{N2G.Transform}},
 \code{\link{N2G.Fit}}    ,         \code{\link{N2G}} ,          
 \code{\link{N2G.Inverse}}   ,         \code{\link{N2G.Region}}
}
\examples{

## simulate image
d <- c(100, 100, 1)
y <- array(0, dim = d)
m <- y
m[, , ] <- 1

z.init <- 2 * m
z.init[20:40, 20:40, 1] <- 1
z.init[50:70, 50:70, 1] <- 3

y[z.init == 1] <- -rgamma(sum(z.init == 1), 4, 1)
y[z.init == 2] <- rnorm(sum(z.init == 2))
y[z.init == 3] <- rgamma(sum(z.init == 3), 4, 1)

mask <- 1 * (y < 1000)

## fit spatial mixture model
ans <- N2G.Spatial.Mixture(y, par.start = c(4, 2, 4, 2, 0.9, 0.05), ksize = 3, ktype = "2D", mask = m) 

## plot original image, standard mixture model estimate and spatial mixture
## model estimate

par(mfrow = c(1, 3))
image(y[, , 1])
image(y[, , 1] > ans$lims[1]) ## this line plots the results of a Non-Spatial Mixture Model
image(ans$p.map[, , 1] > 0.5) ## this line plots the results of the Spatial Mixture Model


}
\keyword{utilities}

\eof
\name{N2G.Transform}
\alias{N2G.Transform}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Transform parameters of N2G model so as to lie on the real line.}
\description{Transform parameters of N2G model so as to lie on the real line
}
\usage{
N2G.Transform(par)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{par}{Parameter vector for N2G model.}
}
\details{Transformation required for optimization.
}
\value{Returns the transformed parameters.
}
\author{J. L. Marchini}

\seealso{\code{\link{N2G.Class.Probability}},  \code{\link{N2G.Likelihood.Ratio}},  \code{\link{N2G.Spatial.Mixture}},
 \code{\link{N2G.Density}} ,         \code{\link{N2G.Likelihood}} ,
 \code{\link{N2G.Fit}}    ,         \code{\link{N2G}} ,          
 \code{\link{N2G.Inverse}}   ,         \code{\link{N2G.Region}}
}

\keyword{utilities}

\eof
\name{NonLinearSmoothArray}
\alias{NonLinearSmoothArray}
\title{Non-linear spatial smmothing of 3D and 4D arrays.}
\description{Smooths the values in an array spatially using a weighting
  kernel that doesn't smooth across boundaries.}
\usage{
NonLinearSmoothArray(x, voxdim=c(1, 1, 1), radius=2, sm=3, mask=NULL)
}
\arguments{
  \item{x}{The array to be smoothed.}
  \item{voxdim}{The voxel dimensions of the array.}
  \item{radius}{The radius of the spatial smoothing}
  \item{sm}{The standard deviation of the Gaussian smoothing kernel.}
  \item{mask}{Optional mask for smoothing.}
}
\details{For a 3D array the smoothed values are obtained through a
  weighted sum of the surrounding voxel values within the specfied
  radius. The weights are calculated using a
  Gaussian kernel function applied to the differences between the voxel
  and its surrounding voxels. In this way the smoothing is anisotropic.

  For a 4D array the first 3 dimensions represent space and the fourth
  represents time. Therefore, each spatial location contains a time series of
  values. These time series are smoothed spatially in an anisotropic
  fashion. The sum of squared differences between each pair of time
  series are used to define the smoothing weights.
}
\value{The smoothed array is returned.}
\author{J. L. Marchini}

\seealso{\code{\link{GaussSmoothArray}}}

\examples{

#3D array
d<-rep(10,3)
a<-array(3,dim=d)
a[,5:10,5:10]<-7
a<-a+array(rnorm(n=1000,sd=1),dim=d)

h<-NonLinearSmoothArray(a,voxdim=c(1,1,1),radius=2,sm=3)

par(mfrow=c(2,2))
image(a[1,,],zlim=c(-1,12));title("Before smoothing")
image(h[1,,],zlim=c(-1,12));title("After smoothing")
persp(a[1,,],zlim=c(-1,12))
persp(h[1,,],zlim=c(-1,12))

#4D array
d<-c(10,10,10,20)
a<-array(1,dim=d)
a[,,6:10,]<-2
a<-a+array(rnorm(20000,sd=.1),dim=d)

h<-NonLinearSmoothArray(a,voxdim=c(1,1,1),radius=2,sm=3)

par(mfrow=c(2,2),mar=c(0,0,0,0))
for(i in 1:10){
    for(j in 10:1){
        plot(a[1,i,j,],type="l",ylim=c(0,3),axes=FALSE);box()
        lines(h[1,i,j,],col=2)
    }}

}
\keyword{utilities}

\eof
\name{Sim.3D.GRF}
\alias{Sim.3D.GRF}

\title{Simulate a GRF}
\description{Simulates a Gaussian Random Field with specified dimensions and
  covariance structure.}
\usage{
Sim.3D.GRF(d, voxdim, sigma, ksize, mask = NULL, type = c("field", "max"))
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{d}{A vector specifying the dimensions of a 3D or 4D array.}
  \item{voxdim}{The dimensions of each voxel.}
  \item{sigma}{The 3D covariance matrix of the field.}
  \item{ksize}{The size (in voxels) of the kernel with which to filter
    the independent field.}
  \item{mask}{A 3D mask for the field.}
  \item{type}{If type == "field" then the simulated field together with
    the maximum of the field is returned. If type == "max" then the
    maximum of the field is returned.}
}
\details{The function works by simulating a Gaussian r.v at each voxel
  location and then smoothing the field with a discrete filter to obtain
  a field with the desired covariance structure.
}
\value{
  \item{mat}{Contains the simulated field if type == "field", else NULL}
  \item{max}{The maximum value of the simulated field.}
}
\author{J. L. Marchini}


\seealso{\code{\link{GaussSmoothArray}},\code{\link{GaussSmoothKernel}}}

\examples{

d <- c(64, 64, 21)
FWHM <- 9
sigma <- diag(FWHM^2, 3) / (8 * log(2))
voxdim <- c(2, 2, 4)
msk <- array(1, dim = d)

field <- Sim.3D.GRF(d = d, voxdim = voxdim, sigma = sigma, ksize = 9, mask = msk, type = "max")

}
\keyword{utilities}

\eof
\name{Sim.3D.GammaRF}
\alias{Sim.3D.GammaRF}
\title{Simulate Gamma distributed Random Field}
\description{Simulates a Gamma distributed random field by simulating a
  Gaussian Random Field and transforming it to be Gamma distributed.
}
\usage{
Sim.3D.GammaRF(d, voxdim, sigma, ksize, mask, shape, rate)
}
\arguments{
  \item{d}{A vector specifying the dimensions of a 3D or 4D array.}
  \item{voxdim}{The dimensions of each voxel.}
  \item{sigma}{The 3D covariance matrix of the field.}
  \item{ksize}{The size (in voxels) of the kernel with which to filter
    the independent field.}
  \item{mask}{A 3D mask for the field.}
  \item{shape}{The shape parameter of the Gamma distribution.}
  \item{rate}{The rate parameter of the Gamma distribution.}
}
\value{A 3D array containing the simulated field
}
\author{J. L. Marchini}
\examples{

d <- c(64, 64, 21)
FWHM <- 9
sigma <- diag(FWHM^2, 3) / (8 * log(2))
voxdim <- c(2, 2, 4)
m <- array(1, dim = d)

a <- Sim.3D.GammaRF(d = d, voxdim = voxdim, sigma = sigma, 
                    ksize = 9, mask = m, shape = 6, rate = 1)

}
\keyword{utilities}

\eof
\name{SmoothEst}
\alias{SmoothEst}
\title{Estimate the variance-covariance matrix of a Gaussian random field}
\description{Estimate the variance-covariance matrix of a Gaussian random field
}
\usage{
SmoothEst(mat, mask, voxdim, method = "Forman")
}
\arguments{
  \item{mat}{3D array that is the Gaussian Random Field.}
  \item{mask}{3D mask array.}
  \item{voxdim}{Vector of length 3 containing the voxel dimensions.}
  \item{method}{The estimator to use. method = "Forman" (the default) uses the
    estimator proposed in [1]. method = "Friston" uses the estimator
    proposed in [2, 3], but tis can be biased when the amount of smoothing
    is small compared to the size of each voxel (see [1] for more
    details and example below)}
}
\details{Calculates the varaince-covariance matrix using the variance
  covariance matrix of partial derivatives.
}
\value{A (3x3) diagonal matrix.
}
\author{J. L. Marchini}

\references{[1] Stephen D. Forman et al. (1995) Improved
  assessment of significant activation in functional magnetic resonance
  imaging (fMRI): Use of a cluster-size threshold. Magnetic Resonance in Medicine, 33:636-647.

  [2] Karl J. Friston et al. (1991) Comparing functional (PET) images: the
  assessment of significant change. J. Cereb. Blood Flow
  Metab. 11:690-699. 

  [3] Stefan J. Kiebel et al. (1999) Robust smoothness estimation in
  statistical parametric maps using standardized residuals from the
  general linear model. NeuroImage, 10:756-766.
}


\examples{

###############
## EXAMPLE 1 ##
###############
## example that illustrates the bias of the Friston
## method when smoothing is small compared to voxel size
## NB. The presence of bias becomes clearer if the
##     simulations below are run about 100 times and
##     the results averaged

ksize <- 13
d <- c(64, 64, 64)
voxdim <- c(1, 1, 1)
FWHM <- 2 ## using a small value of FWHM (=2) compared to voxel size (=1)
sigma <- diag(FWHM^2, 3) / (8 * log(2))
mask <- array(1, dim = d)
num.vox <- sum(mask)

grf <- Sim.3D.GRF(d = d, voxdim = voxdim, sigma = sigma, ksize = ksize, mask = mask, type = "field")$mat
               
sigma
SmoothEst(grf, mask, voxdim, method = "Friston")
SmoothEst(grf, mask, voxdim, method = "Forman") ## compared to sigma
##the Forman estimator is better (on average) than the Friston estimator

###############
## EXAMPLE 2 ##
###############
## increasing the amount of smoothing decreases the bias of the Friston estimator

ksize <- 13
d <- c(64, 64, 64)
voxdim <- c(1, 1, 1)
FWHM <- 5 ## using a large value of FWHM (=5) compared to voxel size (=1)
sigma <- diag(FWHM^2, 3) / (8 * log(2))
mask <- array(1, dim = d)
num.vox <- sum(mask)

grf <- Sim.3D.GRF(d = d, voxdim = voxdim, sigma = sigma, ksize = ksize, mask = mask, type = "field")$mat

SmoothEst(grf, mask, voxdim, method = "Friston")
SmoothEst(grf, mask, voxdim, method = "Forman")                
sigma

}
\keyword{utilities}

\eof
\name{Threshold.Bonferroni}
\alias{Threshold.Bonferroni}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Calculates Bonferroni Threshold}
\description{Calculate the Bonferroni threshold for n iid tests that
  results in an overall p-value of p.val. The tests can be distributed
  as Normal, t or F.
}
\usage{
Threshold.Bonferroni(p.val, n, type = c("Normal", "t", "F"), df1 = NULL, df2 = NULL)
}
\arguments{
  \item{p.val}{The required overall p-value.}
  \item{n}{The number of tests.}
  \item{type}{The distribution of the tests. One of "Normal", "t" or "F"}
  \item{df1}{The degrees of freedom of the t-distribution or the first
    degrees of freedom parameter for the F distribution.}
  \item{df2}{The second degrees of freedom parameter for the F distribution.}
}
\value{Returns the Bonferroni threshold.
}

\examples{
Threshold.Bonferroni(0.05, 1000)

Threshold.Bonferroni(0.05, 1000, type = c("t"), df1 = 20)

Threshold.Bonferroni(0.05, 1000, type = c("F"), df1 = 3, df2 = 100)

}
\keyword{utilities}

\eof
\name{Threshold.FDR}
\alias{Threshold.FDR}
\title{False Discovery Rate (FDR) Threshold}
\description{Calculates the False Discovery Rate (FDR) threshold for a
  given vector of statistic values..
}
\usage{
Threshold.FDR(x, q, cV.type = 2, type = c("Normal", "t", "F"), df1 = NULL, df2 = NULL)
}
\arguments{
  \item{x}{A vector of p-values.}
  \item{q}{The desired False Discovery Rate threshold.}
  \item{cV.type}{A flag that specifies the assumptions about the joint
    distribution of p-values. Choose cV.type = 2 for fMRI data (see
    Genovese et al (2001)}
  \item{type}{The distribution of the statistic values. Either "Normal",
    "t" or "F".}
  \item{df1}{The degrees of freedom of the t-distribution or the first
    degrees of freedom parameter for the F distribution.}
  \item{df2}{The second degrees of freedom parameter for the F distribution.}
}

\value{Returns the FDR threshold.
}
\references{Genovese et al. (2001) Thresholding of Statistical Maps in
  Functional NeuroImaging Using the False Discovery Rate.}
\author{J. L. Marchini}

\examples{
x <- c(rnorm(1000), rnorm(100, mean = 3))
Threshold.FDR(x = x, q = 0.20, cV.type = 2) 
}
\keyword{utilities}

\eof
\name{Threshold.RF}
\alias{Threshold.RF}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Random Field Theory Thersholds.}
\description{Calculates the Random Field theory threshold to give that
  results in a specified p-value.
}
\usage{
Threshold.RF(p.val, sigma, voxdim = c(1, 1, 1), num.vox, type = c("Normal", "t"), df = NULL)
}
\arguments{
  \item{p.val}{The required p-value.}
  \item{sigma}{The 3D covariance matrix of the random field.}
  \item{voxdim}{The dimesnions of a voxel.}
  \item{num.vox}{The number of voxels that constitute the random field.}
  \item{type}{The type of random field, "Normal" or "t".}
  \item{df}{The degrees of the t distributed field.}
}
\details{Calculates the threshold that produces an expected Euler
  characteristic equal to the required p-value.
}
\value{Returns the Random Field threshold.
}
\author{J. L. Marchini}

\seealso{\code{\link{EC.3D}}}

\examples{
a <- Threshold.RF(p.val = 0.05, sigma = diag(1, 3), voxdim = c(1, 1, 1), num.vox = 10000)

EC.3D(a, sigma = diag(1, 3), voxdim = c(1, 1, 1), num.vox = 10000)

}
\keyword{utilities}

\eof
\name{cluster.threshold}
\alias{cluster.threshold}
\title{Cluster threshold an array.}
\description{Calculate contiguous clusters of locations in a 3D array that are
  above some threshold and with some minimum size.
}
\usage{
cluster.threshold(x, nmat = NULL, level.thr = 0.5, size.thr)
}
\arguments{
  \item{x}{A 3D array}
  \item{nmat}{A matrix with 3 columns specifying the neighbourhood
    system. Default is 6 nearest neighbours in 3D.}
  \item{level.thr}{The level at which to threshold the array
    values. Default is 0.5 and is designed to cluster 0-1 arrays.}
  \item{size.thr}{The cluster size threshold.}
}
\value{Returns an array of the same size as x with a 1 at all locations
  which have a value above level.thr and are in a cluster of similiar
  locations with size greater than size.thr. 
}
\author{J. L. Marchini}

\examples{

x <- array(0, dim = c(64, 64, 21))
x[10:20, 10:20, 1:5] <- 1
x[30:40, 30:40, 6:7] <- 1
x[50, 50, 8:9] <- 1

a <- cluster.threshold(x, size.thr = 400)
sum(x) ## should be 849
sum(a) ## should be 605

}
\keyword{utilities}

\eof
\name{cov.est}
\alias{cov.est}
\title{Estimates the covariance between neighbouring voxels}
\description{Estimates the covariance between neighbouring voxels using
   a specified neighbourhood system.
}
\usage{
cov.est(mat, mask, nmat)
}
\arguments{
  \item{mat}{3D array of voxel values.}
  \item{mask}{Array with sam dimension as mat that is 1/0 for voxels to
    be included/excluded.}
  \item{nmat}{Neighbourhood matrix.}
}
\value{The estimated covariance
}
\author{J. L. Marchini}

\examples{
ksize <- 9
d <- c(64, 64, 21)
FWHM <- 9
sigma <- diag(FWHM^2, 3) / (8 * log(2))
voxdim <- c(2, 2, 4)

filtermat <- GaussSmoothKernel(voxdim, ksize, sigma)

mask <- array(1, dim = d)
num.vox <- sum(mask)

mat <- Sim.3D.GRF(d = d, voxdim = voxdim, sigma = sigma, ksize = ksize, mask = mask, type = "field")$mat

nmat <- expand.grid(-1:1, -1:1, -1:1)
nmat4 <- nmat[c(11, 13, 15, 17), ]

cov <- cov.est(mat, mask, nmat4)
}
\keyword{utilities}

\eof
\name{f.analyze.file.summary}
\alias{f.analyze.file.summary}
\title{prints summary of .img file contents}
\description{Prints a summary of the contents of an ANALYZE .img file using
  the associated .hdr header file.}
\usage{f.analyze.file.summary(file)}
\arguments{\item{file}{The location of .img file to be read}}
\value{A print out containing information about the .img file. This includes
    File name, Data Dimension, X dimension, Y dimension, Z dimension, Time dimension, Voxel dimensions, Data type}
\seealso{  \code{\link{f.read.analyze.header}},
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.read.analyze.ts}},
  \code{\link{f.write.analyze}},
  \code{\link{f.read.analyze.volume}},
  \code{\link{f.spectral.summary}},
  \code{\link{f.write.array.to.img.2bytes}},
  \code{\link{f.write.array.to.img.float}},
  \code{\link{f.write.list.to.hdr}},
   \code{\link{f.basic.hdr.list.create}}   }
 \examples{
f.analyze.file.summary(system.file("example.img", package="AnalyzeFMRI"))
}
\keyword{utilities}


\eof
\name{f.analyzeFMRI.gui}
\alias{f.analyzeFMRI.gui}
\title{starts AnalyzeFMRI GUI}
\description{Starts an R/tk interfaced GUI that allows the user to
  explore an fMRI dataset stored in an ANALYZE format file using the
  functions of the AnalyzeFMRI package.
}
\usage{
f.analyzeFMRI.gui()
}
\value{No value is returned
}
\keyword{utilities}


\eof
\name{f.basic.hdr.list.create}
\alias{f.basic.hdr.list.create}
\title{creates basic .hdr list}
\description{Creates a basic list that can be used to write a .hdr file
}
\usage{f.basic.hdr.list.create(mat, file.hdr)
}

\arguments{
  \item{mat}{\code{mat} Array that is to be converted to a .img file}
  \item{file.hdr}{\code{file.hdr} Name of the .hdr file that will be created }
}
\value{Returns a list of all the fields needed to create a .hdr file
  (see the functions code for details).}
\seealso{ 
  \code{\link{f.write.list.to.hdr}},
  \code{\link{f.analyze.file.summary}} 
}
\examples{
a<-array(rnorm(20*30*40*3),dim=c(20,30,40,3))
file<-"temp.hdr"
f.basic.hdr.list.create(a, file)
}
\keyword{utilities}


\eof
\name{f.ica.fmri}
\alias{f.ica.fmri}
\title{Applies Spatial ICA (Independent Component Analysis) to fMRI datasets}
\description{Decomposes an fMRI dataset into a specified number of
  Spatially Independent Components maps and associated time-courses using the FastICA algorithm}
\usage{
f.ica.fmri(file.name, n.comp, norm.col=TRUE, fun="logcosh", maxit=1000,
alg.type="parallel", alpha=1, tol=1e-04, mask.file.name=NULL, slices=NULL)
}
\arguments{
  \item{file.name}{path to fMRI dataset (ANALYZE format .img file) }
  \item{n.comp}{number of components to extract}
  \item{norm.col}{a logical value indicating whether each voxel time
    series should be standardised to have zero mean and unit variance
    before the ICA algorithm is applied (default=TRUE recommended in practice)}
  \item{fun}{the functional form of the G function used in the
    approximation to negentropy (see details)}
  \item{maxit}{maximum number of iterations to perform}
  \item{alg.type}{if \code{alg.typ=="deflation"} the components are
    extracted one at a time (the default).
    if \code{alg.typ=="parallel"} the components are extracted
    simultaneously.}
  \item{alpha}{constant in range [1,2] used in approximation to
    negentropy when \code{fun=="logcosh"}}
  \item{tol}{a positive scalar giving the tolerance at which the
    un-mixing matrix is considered to have converged.}
  \item{mask.file.name}{Optional path to file containing a 0/1 mask for
    the dataset}
  \item{slices}{Optional vector of slices to be included}
}
\details{The fMRI dataset is rearranged into a 2-dimensional data matrix
  X, where the column vectors are voxel time-series. A mask is used to
  specify which voxels are included. If this is not supplied by the user
  then a mask is constructed automatically using a 10\% intensity threshold.

  The data matrix is considered to be a linear combination of
  non-Gaussian (independent) components i.e. X = AS where rows of S
  contain the independent components and A is a linear mixing
  matrix. In short ICA attempts to 'un-mix' the data by estimating an
  un-mixing matrix U where UX = S.

  Under this generative model the measured 'signals' in X will tend to
  be 'more Gaussian' than the source components (in S) due to the Central
  Limit Theorem. Thus, in order to extract the independent
  components/sources we search for an un-mixing matrix U that
  maximizes the non-gaussianity of the sources.

  In FastICA, non-gaussianity is measured using approximations to
  negentropy (J) which are more robust than kurtosis based measures and fast
  to compute.

  The approximation takes the form

  \eqn{J(y)=[E{G(y)}-E{G(v)}]^2} where \eqn{v} is a N(0,1) r.v

  The following choices of G are included as options
  \eqn{G(u)=\frac{1}{\alpha} \log \cosh (\alpha u)} and \eqn{G(u)=-\exp(\frac{-u^2}{2})}

  The FastICA algorithm is used to 'un-mix' the data and recover
  estimates of the mixing matrix A and the source matrix S. Rows of the
  source matrix S represent spatially independent components of the
  dataset (these are arranged spatially in the output). Columns of A
  contain the associated time-courses of the independent components.

  Pre-processing involves removing the mean of each row of the data
  matrix and (optionally) standardizing the columns of the data matrix
  to have zero mean and unit variance.

  All computations are done using C code. This avoids reading the entire
  dataset into R and thus saves memory space.
  
}
\value{A list containing the following components
  
  \item{A}{estimated mixing matrix}
  \item{S}{estimated source matrix that has been rearranged spatially
    i.e. S is a 4-D array and S[,,,i] contains the 3-D map of the ith
    component}
  \item{file}{the name of the data file}
  \item{mask}{the name of the mask file}
}
\references{A. Hyvarinen and E. Oja (2000) Independent Component
  Analysis: Algorithms and Applications, Neural Networks,
  13(4-5):411-430
  
  Beckmann C. (2000) Independent Component Analysis for fMRI. First Year
  D.Phil Report, Dept. of Engineering Science, University of Oxford.}
\author{J L Marchini <marchini@stats.ox.ac.uk> and C Heaton <chrisheaton99@yahoo.com>}

\seealso{\code{\link{f.ica.fmri.gui}},\code{\link{f.plot.ica.fmri}} }

\keyword{utilities}


\eof
\name{f.ica.fmri.gui}
\alias{f.ica.fmri.gui}
\title{tcltk GUI to apply ICA to fMRI datasets}
\description{The GUI provides a quick and easy to use interface for
  applying spatial ICA to fMRI datasets. Computations are done in C for
  speed and low memory usage. 
}
\usage{
f.ica.fmri.gui()
}
\details{The user is required to enter the location of the fMRI dataset
  (stored in the ANALYZE format) and (optionally) a mask for the
  dataset. If no mask is supplied then an option to create mask is
  available. There is option to normalize the columns of the data matrix
  and to exclude the top and bottom slices (which are sometimes affected
  by the registration procedures).

Once completed, the user has the option of saving the results to an R
object or viewing the estimated components. The slices of each component
map are plotted sequentially in a grid followed by the components
associated time-course and that time-courses periodogram/power spectrum.}
\value{
  \item{User named R object (optional)}{Once completed, the user has the
    option of saving the results to an R object named by the user.}
}
\author{J L Marchini <marchini@stats.ox.ac.uk> and C Heaton <chrisheaton99@yahoo.com>}

\seealso{\code{\link{f.ica.fmri}},\code{\link{f.plot.ica.fmri}}}

\keyword{utilities}

\eof
\name{f.plot.ica.fmri}
\alias{f.plot.ica.fmri}
\title{Plots a specified component from the output of f.ica.fmri}
\description{Plots a specified component from the output of f.ica.fmri
}
\usage{
f.plot.ica.fmri(obj.ica, comp, cols)
}
\arguments{
  \item{obj.ica}{R object returned by the function f.ica.fmri}
  \item{comp}{number of the component to plot}
  \item{cols}{optional vector of colours to use for plotting}
}
\details{The slices of the specified component map are plotted
  sequentially in a grid followed by the components associated
  time-course and that time-courses periodogram/power spectrum
}
\author{J L Marchini <marchini@stats.ox.ac.uk> and C Heaton <chrisheaton99@yahoo.com>}

\seealso{\code{\link{f.ica.fmri}},\code{\link{f.ica.fmri.gui}}}

\keyword{utilities}


\eof
\name{f.plot.ica.fmri.jpg}
\alias{f.plot.ica.fmri.jpg}
\title{Plot the components of the ouput of f.ica.fmri to a series of
  jpeg files}
\description{This function allows the compact graphical storage of the
  output of a spatial ICA decomposition of an fMRI dataset. each
  component is plotted to a jpeg.
}
\usage{
f.plot.ica.fmri.jpg(ica.obj, file="./ica", cols=heat.colors(100), width=700, height=700)
}
\arguments{
  \item{ica.obj}{Object that is the output of f.ica.fmri}
  \item{file}{The component i will be plotted in file file.comp.i.jpeg}
  \item{cols}{Optional colour vector for plotting the components}
  \item{width}{Width of jpeg images}
  \item{height}{Height of jpeg images}
}
\author{J L Marchini}


\seealso{\code{\link{f.ica.fmri}},
  \code{\link{jpeg}}
}

\keyword{utilities}



 






















\eof
\name{f.read.analyze.header}
\alias{f.read.analyze.header}
\title{read Analyze header file}
\description{Reads the ANALYZE image format .hdr header file into a
  list.}
\usage{f.read.analyze.header(file)}
\arguments{\item{file}{The .hdr file to be read}}
\value{A list containing the information in the fields of the .hdr
  file. Only the ones considered useful are included. See comments
  included in the function definition if you want to extend the amount
  of information extracted and stored.
\item{swap}{TRUE or FALSE variable indicating whether files are big or little endian}
\item{file.name}{path name of the .img file}
\item{dim}{vector of image dimensions. The first entry specifies the number
  of dimensions}
\item{vox.units}{specifies the spatial units of measure for a voxel}
\item{cal.units}{specifies the name of the calibration unit i.e. pixel,voxel}
\item{datatype}{integer indicator of data storage type for each voxel}
\item{data.type}{character vector indicating data storage type for each voxel}
\item{bit.pix}{the number of bits per voxel}
\item{pixdim}{parallel vector to dim giving real world voxel unit measurements}
\item{glmax}{maximum voxel value}
\item{glmin}{minimum voxel value}}
\seealso{
  \code{\link{f.analyze.file.summary}}}
\examples{
f.read.analyze.header(system.file("example.hdr", package="AnalyzeFMRI"))
}
\keyword{utilities}




\eof
\name{f.read.analyze.slice}
\alias{f.read.analyze.slice}
\title{read one slice from a .img file}
\description{Reads in a specific slice from an ANALYZE .img image format
  file into an array.}
\usage{f.read.analyze.slice(file, slice, tpt)}
\arguments{
  \item{file}{The .img file to be read from}
  \item{slice}{The number of the slice (assumed to be the 3rd dimension)}
  \item{tpt}{The number of the scan that the slice is to be taken from}}
\details{The entire dataset is assumed to be 4D and a slice is extracted
  that is referenced by specifying the last two dimensions of the
  dataset i.e.slice and tpt.}
\value{An array containing the slice}
\seealso{
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.read.analyze.ts}},
  \code{\link{f.read.analyze.volume}}
 
}
\examples{
a<-f.read.analyze.slice(system.file("example.img", package="AnalyzeFMRI"),10,1)
dim(a)
}
\keyword{utilities}

\eof
\name{f.read.analyze.slice.at.all.timepoints}
\alias{f.read.analyze.slice.at.all.timepoints}

\title{reads a slice at all time points from a .img file}
\description{Reads in a slice of a .img file at all time points into an array}
\usage{f.read.analyze.slice.at.all.timepoints(file, slice)
}
\arguments{
  \item{file}{\code{file} The location of the .img file}
  \item{slice}{\code{slice} The number of the slice to be read in}
}
\value{An array containing the slice at all time points
}
\seealso{
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.ts}},
  \code{\link{f.read.analyze.volume}}   

}
\examples{
a<-f.read.analyze.slice.at.all.timepoints(system.file("example.img", package="AnalyzeFMRI"),10)
dim(a)
}
\keyword{utilities}

\eof
\name{f.read.analyze.tpt}
\alias{f.read.analyze.tpt}
\title{Read in a volume at one time point}
\description{Given a 4D ANALYZE .img/.hdr image pair this function can
  read in the 3D volume of measurements at a specific time point.}
\usage{f.read.analyze.tpt(file, tpt)}
\arguments{
  \item{file}{The .img file.} 
  \item{tpt}{The time point to read in.}}
\details{Given a 4D ANALYZE .img/.hdr image pair this function can
  read in the 3D volume of measurements at a specific time point.}
\value{A 3D array containing the volume.}\
seealso{
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.write.analyze}}, }
\examples{
f.read.analyze.tpt(system.file("example.img", package="AnalyzeFMRI"),1)
}
\keyword{utilities}

\eof
\name{f.read.analyze.ts}
\alias{f.read.analyze.ts}
\title{read in one voxel time series}
\description{Given a 4D ANALYZE .img/.hdr image pair this function can
  read in the time series from a specified position in 3D into a vector.}
\usage{f.read.analyze.ts(file, x, y, z)}
\arguments{
  \item{file}{The .img file}                 
  \item{x}{The x-coordinate}
  \item{y}{The y-coordinate}
  \item{z}{The z-coordinate}}
\details{Given a 4D ANALYZE .img/.hdr image pair this function can
  read in the time series from a specified position in 3D into a vector.}
\value{A vector containing the time series}
\seealso{
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.write.analyze}}, }
\examples{
f.read.analyze.ts(system.file("example.img", package="AnalyzeFMRI"),30,30,10)
}
\keyword{utilities}

\eof
\name{f.read.analyze.volume}
\alias{f.read.analyze.volume}
\title{read whole .img file}
\description{Reads the ANALYZE image format .img file into an array.}
\usage{f.read.analyze.volume(file)}
\arguments{\item{file}{The location of the .img file to be read}}
\value{An array with the appropriate dimensions containing the image
  volume. A print out of the file information is also given. The
  function assumes that the corresponding .hdr file is in the same
  directory as the .img file. }
\seealso{
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.read.analyze.ts}}
}
\examples{
a<-f.read.analyze.volume(system.file("example.img", package="AnalyzeFMRI"))
dim(a)
}
\keyword{utilities}


\eof
\name{f.spectral.summary}
\alias{f.spectral.summary}
\title{plots graphical summary of spectral properties of an fMRI dataset}
\description{For an analyze .img file the periodogram of the time series are divided by a flat spectral estimate using the median periodogram ordinate. The resulting values are then combined within each Fourier frequency and quantiles are plotted against frequency. This provides a fast look at a fMRI dataset to identify any artifacts that reside at single frequencies.
}
\usage{f.spectral.summary(file, mask.file, ret.flag=FALSE)}

\arguments{
  \item{file}{\code{file} The location of .img file  }
  \item{mask.file}{\code{mask.file} Optional location of a .img file
    containing a mask. If not given then one is created.}
  \item{ret.flag}{\code{ret.flag} flag specifying whether to return the
    array of quantiles at each frequency}
}
\value{If \code{ret.flag = TRUE} the an array of quantiles at each
  frequency is returned
}
\seealso{
  \code{\link{f.analyze.file.summary}}}     
\keyword{utilities}

\eof
\name{f.write.analyze}
\alias{f.write.analyze}
\title{writes an array to a .img/.hdr pair}
\description{Creates a .img and .hdr pair of files from a given array}
\usage{f.write.analyze(mat,file,size,pixdim,vox.units,cal.units)}
\arguments{\item{mat}{An array}
  \item{file}{The name of the file to be written, without .img or .hdr
    suffix}
  \item{size}{Specify the format of the .img file. Either "float" (for 4
    byte floats) or "int" (2 byte integers) or "char" (1 byte integers).}
  \item{pixdim}{A vector of length 3 specifying the voxel dimensions in
    mm}
  \item{vox.units}{String specifying the spatial units of measure for a
    voxel}
  \item{cal.units}{String specifying the name of calibration unit}
}

\value{Nothing is returned}
\seealso{
  \code{\link{f.write.array.to.img.8bit}},
  \code{\link{f.write.array.to.img.2bytes}},
  \code{\link{f.write.array.to.img.float}} }    
\examples{
a<-array(rnorm(20*30*40*3),dim=c(20,30,40,3))
file<-"temp"
f.write.analyze(a,file,size="float")
f.analyze.file.summary("temp.img")
}
\keyword{utilities}

\eof
\name{f.write.array.to.img.2bytes}
\alias{f.write.array.to.img.2bytes}
\title{write array of 2 byte integers}
\description{Writes an array to a .img file of 2 byte integers}
\usage{f.write.array.to.img.2bytes(mat,file)}
\arguments{\item{mat}{An array}
  \item{file}{The name of the file to be written, preferably with .img suffix}
}
\value{Nothing is returned}
\seealso{
  \code{\link{f.write.analyze}}
  \code{\link{f.write.array.to.img.float}}  }
\keyword{utilities}

\eof
\name{f.write.array.to.img.8bit}
\alias{f.write.array.to.img.8bit}
\title{write array of 1 byte integers}
\description{Writes an array to a .img file of 1 byte integers}
\usage{f.write.array.to.img.8bit(mat,file)}
\arguments{\item{mat}{An array}
  \item{file}{The name of the file to be written, preferably with .img suffix}
}
\value{Nothing is returned}
\seealso{
  \code{\link{f.write.analyze}},
  \code{\link{f.write.array.to.img.float}},
  \code{\link{f.write.array.to.img.2bytes}}  }
\keyword{utilities}

\eof
\name{f.write.array.to.img.float}
\alias{f.write.array.to.img.float}
\title{write array of 4 byte floats}
\description{Writes an array to a .img file of 4 byte floats}
\usage{f.write.array.to.img.float(mat,file)}
\arguments{\item{mat}{An array}
  \item{file}{The name of the file to be written, preferably with .img
    suffix}}
 \seealso{
  \code{\link{f.write.analyze}},
  \code{\link{f.write.array.to.img.2bytes}} ,
  \code{\link{f.write.array.to.img.8bit}}   }
\value{Nothing is returned}
\keyword{utilities}

\eof
\name{f.write.list.to.hdr}
\alias{f.write.list.to.hdr}
\title{writes a .hdr file}
\description{Writes a list of attributes to a .hdr file}
\usage{f.write.list.to.hdr(L,file)}
\arguments{\item{L}{A list of the all the fields included in a .hdr file}
  \item{file}{The name of the file to write, preferably with .hdr suffix}}
\value{Nothing is returned}
\seealso{
   \code{\link{f.basic.hdr.list.create}}    } 
 \examples{
a<-array(rnorm(20*30*40*3),dim=c(20,30,40,3))
file<-"temp.hdr"
b<-f.basic.hdr.list.create(a, file)
f.basic.hdr.list.create(b,file)}
\keyword{utilities}

\eof
\name{model.2.cov.func}
\alias{model.2.cov.func}
\title{Calculates covariance from Hartvig Model 2}
\description{Calculates covariance from Hartvig Model 2
}
\usage{
model.2.cov.func(g, par)
}
\arguments{
  \item{g}{The value of gamma}
  \item{par}{A vector of parameters from the N2G model}
}
\value{The calculated covariance
}
\references{Hartvig, N. V. and Jensen, J. L (2000) Spatial Mixture
  Modelling of fMRI Data, Human Brain Mapping 11:233--248}
\author{J. L. Marchini}

\keyword{utilities}

\eof
\name{model.2.est.gamma}
\alias{model.2.est.gamma}
\title{Estimate gamma for Model 2 of Hartvig and Jensen (2000)}
\description{Estimate gamma for Model 2 of Hartvig and Jensen (2000)
}
\usage{
model.2.est.gamma(cov, par)
}
\arguments{
  \item{cov}{An estimate of the spatial covariance}
  \item{par}{N2G model parameter estimates}
}
\value{The estimate of gamma
}
\references{Hartvig, N. V. and Jensen, J. L (2000) Spatial Mixture
  Modelling of fMRI Data, Human Brain Mapping 11:233--248}
\author{J. L. Marchini}

\keyword{utilities}

\eof
